#
# spec file for package texworks
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2007-09 by Jonathan Kew.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           texworks
Version:        0.4.6
Release:        0
Summary:        TeXshop-like TeX Editor
License:        GPL-2.0+
Group:          Productivity/Publishing/TeX/Frontends
Url:            http://www.tug.org/texworks/
Source0:        https://github.com/TeXworks/texworks/archive/release-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  dbus-1-devel
BuildRequires:  desktop-file-utils
BuildRequires:  hunspell-devel
BuildRequires:  libpoppler-devel >= 0.24
%if 0%{?suse_version} >= 1320
BuildRequires:  libpoppler-qt5-devel >= 0.24
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Script)
BuildRequires:  pkgconfig(Qt5ScriptTools)
BuildRequires:  pkgconfig(Qt5UiTools)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5Xml)
%else
BuildRequires:  libpoppler-qt4-devel >= 0.24
BuildRequires:  libqt4-devel
%endif
BuildRequires:  lua-devel
BuildRequires:  python-devel
BuildRequires:  update-desktop-files
Requires:       dbus-1
Requires:       hunspell
Requires:       poppler-tools
Requires:       texlive-latex
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
The TeXworks project is an effort to build a simple TeX front-end
program (working environment) that will be available for all today’s
major desktop operating systems—in particular, MS Windows (XP and
Vista), typical GNU/Linux distros and other X11-based systems, and
Mac OS X. It is deliberately modeled on Dick Koch’s award-winning
TeXShop for Mac OS X, which is credited with a resurgence of TeX
usage on the Mac platform.

%package plugin-python
Summary:        Plugins to add python scripting to texworks
Group:          Development/Libraries/Python
Requires:       %{name} = %{version}
Requires:       python

%description plugin-python
The TeXworks project is an effort to build a simple TeX front-end
program (working environment) that will be available for all today’s
major desktop operating systems—in particular, MS Windows (XP and
Vista), typical GNU/Linux distros and other X11-based systems, and
Mac OS X. It is deliberately modeled on Dick Koch’s award-winning
TeXShop for Mac OS X, which is credited with a resurgence of TeX
usage on the Mac platform.

This package adds python scripting abitilies to TeXworks.

%package plugin-lua
Summary:        Plugins to add python scripting to texworks
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}
Requires:       lua

%description plugin-lua
The TeXworks project is an effort to build a simple TeX front-end
program (working environment) that will be available for all today’s
major desktop operating systems—in particular, MS Windows (XP and
Vista), typical GNU/Linux distros and other X11-based systems, and
Mac OS X. It is deliberately modeled on Dick Koch’s award-winning
TeXShop for Mac OS X, which is credited with a resurgence of TeX
usage on the Mac platform.

This package adds lua scripting abitilies to TeXworks.

%prep
%setup -q -n texworks-release-%{version}

%build

mkdir build
pushd build
cmake -DCMAKE_INSTALL_PREFIX=%{_prefix} \\\
      -DTW_BUILD_ID="openSUSE" \\\
      -DCMAKE_LIBRARY_OUTPUT_DIRECTORY=%{_lib} \\\
      -DWITH_LUA=ON \\\
      -DWITH_PYTHON=ON \\\
%if 0%{?suse_version} >= 1320      
      -DDESIRED_QT_VERSION="5" \\\
%else
      -DDESIRED_QT_VERSION="4" \\\
%endif
      -DTeXworks_PLUGIN_DIR=%{_libdir}/%{name} \\\
      ..

make %{?_smp_mflags} VERBOSE=1

popd

%install
pushd build
%make_install
%suse_update_desktop_file texworks Publishing WordProcessor
popd

# Package doc files using %%doc, remove them here
for i in COPYING README.md NEWS
do
  rm %{buildroot}%{_datadir}/doc/%{name}/${i}
done

%post
%desktop_database_post

%postun
%desktop_database_postun

%files
%defattr(-,root,root)
%doc COPYING README.md NEWS
%dir %{_datadir}/appdata
%{_datadir}/appdata/texworks.appdata.xml
%{_bindir}/texworks
%{_datadir}/applications/texworks.desktop
%{_datadir}/pixmaps/*.png
%{_mandir}/man1/texworks.1.*

%files plugin-python
%defattr(-,root,root)
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/*PythonPlugin.so

%files plugin-lua
%defattr(-,root,root)
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/*LuaPlugin.so

%changelog
